@@ -6,13 +6,13 @@ import urllib.parse
 import ldap3
 from ldap3.core.exceptions import LDAPException
 
+from trytond.i18n import gettext
+from trytond.model.exceptions import AccessError
 from trytond.transaction import Transaction
 from trytond.pool import PoolMeta
 from trytond.config import config, parse_uri
 from trytond.exceptions import LoginException
 
-__all__ = ['User']
-
 logger = logging.getLogger(__name__)
 section = 'ldap_authentication'
 
@@ -51,14 +51,6 @@ def ldap_server():
 class User(metaclass=PoolMeta):
     __name__ = 'res.user'
 
-    @classmethod
-    def __setup__(cls):
-        super(User, cls).__setup__()
-        cls._error_messages.update({
-                'set_passwd_ldap_user': (
-                    'You can not set the password of ldap user "%s".'),
-                })
-
     @staticmethod
     def ldap_search_user(login, server, attrs=None):
         '''
@@ -109,7 +101,9 @@ class User(metaclass=PoolMeta):
         except LDAPException:
             logger.error('LDAPError when checking password', exc_info=True)
         if find:
-            cls.raise_user_error('set_passwd_ldap_user', (login,))
+            raise AccessError(
+                gettext('ldap_authentication.msg_ldap_user_change_password',
+                    user=login))
 
     @classmethod
     def create(cls, vlist):
@@ -134,7 +128,7 @@ class User(metaclass=PoolMeta):
     @classmethod
     def _login_ldap(cls, login, parameters):
         if 'password' not in parameters:
-            msg = cls.fields_get(['password'])['password']['string']
+            msg = gettext('res.msg_user_password', login=login)
             raise LoginException('password', msg, type='password')
         password = parameters['password']
         try:
@@ -144,18 +138,18 @@ class User(metaclass=PoolMeta):
                 users = cls.ldap_search_user(login, server, attrs=[uid])
                 if users and len(users) == 1:
                     [(dn, attrs)] = users
-                    con = ldap3.Connection(server, dn, password)
-                    if (password and con.bind()):
-                        # Use ldap uid so we always get the right case
-                        login = attrs.get(uid, [login])[0]
-                        user_id = cls._get_login(login)[0]
-                        if user_id:
-                            return user_id
-                        elif config.getboolean(section, 'create_user'):
-                            user, = cls.create([{
-                                        'name': login,
-                                        'login': login,
-                                        }])
-                            return user.id
+                    with ldap3.Connection(server, dn, password) as con:
+                        if (password and con.bind()):
+                            # Use ldap uid so we always get the right case
+                            login = attrs.get(uid, [login])[0]
+                            user_id = cls._get_login(login)[0]
+                            if user_id:
+                                return user_id
+                            elif config.getboolean(section, 'create_user'):
+                                user, = cls.create([{
+                                            'name': login,
+                                            'login': login,
+                                            }])
+                                return user.id
         except LDAPException:
             logger.error('LDAPError when login', exc_info=True)
